@@ -1,6 +1,9 @@
 package Zucchini::Contributors;
+# vim: ts=8 sts=4 et sw=4 sr sta
 use strict;
-use Zucchini::Version;  our $VERSION = $Zucchini::VERSION;
+use warnings;
+
+use Zucchini::Version; our $VERSION = $Zucchini::VERSION;
 
 # this is a dummy package to provide POD
 
